import ParseError from '../../ParseError.js';
/**
 * Although it can be used to parse anything, this is recommended to be used to parse as a specified non-object type
 * @returns the Options object
 */
const parseAsCustomType = (value, parseable) => ({
    orElseGet: (u) => (parseable(value) ? value : u),
    orElseLazyGet: (callBackFunction) => parseable(value) ? value : callBackFunction(),
    orElseGetNull: () => (parseable(value) ? value : null),
    orElseGetUndefined: () => (parseable(value) ? value : undefined),
    orElseThrowDefault: (name) => {
        if (parseable(value)) {
            return value;
        }
        throw ParseError.defaultMessage(name, value, 'object', typeof value);
    },
    orElseThrowCustom: (message) => {
        if (parseable(value)) {
            return value;
        }
        throw ParseError.customizedMessage(message);
    },
});
export default parseAsCustomType;
//# sourceMappingURL=parseAsCustomType.js.map